{{/*
Common labels
*/}}
{{- define "opensearch.labels" -}}
{{ include "opensearch-utils.labels" . }}
{{- end -}}

{{/*
Selector labels
*/}}
{{- define "opensearch.selectorLabels" -}}
{{ include "opensearch-utils.selectorLabels" . }}
{{- end -}}

{{/*
    Region is not required as opensearch clusters are scoped within a region/account.
    This is shortened from typical naming because ES domains have a 28 character limit.
    Steering away from the normal pattern because of strict requirements the OpenSearch
    service imposes on us.
*/}}
{{- define "opensearch._domainName" -}}
{{- .Values.global.env -}}-
{{- required ".Values.domainName is a required value" .Values.domainName -}}
{{- end -}}

{{/*
  Domain name
*/}}
{{- define "opensearch.domainName" -}}
{{- if include "opensearch._domainName" . | replace "_" "-" | trimSuffix "-" | len | int64 | ge 28 -}}
{{- include "opensearch._domainName" . | replace "_" "-" | trimSuffix "-" -}}
{{- else -}}
{{- include "opensearch._domainName" . | replace "_" "-" | trimSuffix "-" | print "\nError: The generated external name is longer than 28 chars. \nPlease provide a shorter .Values.domainName \nGenerated domainName: " | fail -}}
{{- end -}}
{{- end -}}

{{/*
  The kubernetes service name for the db endpoint
*/}}
{{- define "opensearch.clusterEndpoint" -}}
  {{ include "opensearch-utils.namingPrefix" . }}-endpoint.{{ include "opensearch-utils.appsNamespace" . }}.svc.cluster.local
{{- end -}}

{{/*
  The kubernetes sort service name for the db endpoint
*/}}
{{- define "opensearch.clusterEndpointShortName" -}}
  {{ include "opensearch-utils.namingPrefix" . }}-endpoint
{{- end -}}

{{/*
  Check versions for compatible list
*/}}
{{- define "opensearch.getVersion" -}}
{{- if has .Values.engineVersion .Values.compatibleVersions -}}
{{- .Values.engineVersion -}}
{{- else -}}
{{- fail "The engineVersion passed in is not supported in AWS deployments." -}}
{{- end -}}
{{- end -}}

{{- /*
  Return image name for local deployments. Check versions for compatible list + matching the public Opensearch images
  see: https://hub.docker.com/r/opensearchproject/opensearch
*/ -}}
{{- define "opensearch.getLocalImage" -}}
{{- $image := "opensearchproject/opensearch" -}}
{{- if (default nil .Values.localDeployment.image) -}}
{{- .Values.localDeployment.image -}}
{{- else if has .Values.engineVersion .Values.compatibleVersions -}}
  {{- if semverCompare "< 1.1" .Values.engineVersion -}}
{{- printf "%s:%s" $image "1.0.1" -}}
  {{- else if semverCompare "~1.1" .Values.engineVersion -}}
{{- printf "%s:%s" $image "1.1.0" -}}
  {{- else if semverCompare "~1.2" .Values.engineVersion -}}
{{- printf "%s:%s" $image "1.2.4" -}}
  {{- else if semverCompare ">= 1.3 < 2.0" .Values.engineVersion -}}
{{- printf "%s:%s" $image "1" -}}
  {{- else if semverCompare "~2" .Values.engineVersion -}}
{{- printf "%s:%s" $image "2" -}}
  {{- else -}}
fail "The engineVersion passed in is not supported in local deployments."
  {{- end -}}
{{- end -}}
{{- end -}}

{{/*
  The user password secret name
*/}}
{{- define "opensearch.dbUserPassCredentialsSecretName" -}}
  {{ include "opensearch-utils.namingPrefix" . }}-srch-pass
{{- end -}}

{{- /*
  Handles the the master username string
  Moving this here out of gen-primary-secret.sh so that it can be unit tested.

  Looks for a user-supplied value and falls back to namingPrefix. Crops both
  down to 16 chars or less.
*/ -}}
{{- define "opensearch.username" -}}
  {{- $maxLength := 16 -}}
  {{- if .Values.masterUserName }}
    {{- printf .Values.masterUserName | trunc $maxLength }}
  {{- else }}
    {{- splitList "-" (include "opensearch-utils.namingPrefix" .) | last | trunc $maxLength -}}
  {{- end }}
{{- end -}}

{{/*
  The user username secret name
*/}}
{{- define "opensearch.dbUserUsernameCredentialsSecretName" -}}
  {{ include "opensearch-utils.namingPrefix" . }}-srch-user
{{- end -}}

{{/*
  Local Deployment Resource Settings
*/}}
{{- define "opensearch.localDeploymentResourceValues" -}}
requests:
  cpu: {{ .Values.localDeployment.resources.requests.cpu }}
  memory: {{ .Values.localDeployment.resources.requests.memory }}
limits:
  memory: {{ .Values.localDeployment.resources.limits.memory }}
{{- end -}}

{{/*
  Defines the ouput params for -outputs config map
*/}}
{{- define "opensearch.outputCMParams" -}}
arnConfigMap: "{{ include "opensearch-utils.namingPrefix" . }}-arn"
{{- if .Values.existingInfraOverrides.enable }}
domainName: {{ required "You must specify the value for existing Opensearch cluster domainName '.Values.existingInfraOverrides.domainName' to be created."  .Values.existingInfraOverrides.domainName }}
{{ else }}
domainName: {{ include "opensearch.domainName" . }}
{{ end }}
dbServiceClusterEndpointShortName: {{ include "opensearch.clusterEndpointShortName" . }}
dbServiceClusterEndpoint: {{ include "opensearch.clusterEndpoint" . }}
{{- end }}

{{/*
  Defines the ouput params for -arn config map
*/}}
{{- define "opensearch.arnCMParams" -}}
{{- if not ( and .Values.existingInfraOverrides.domainName .Values.existingInfraOverrides.arn .Values.existingInfraOverrides.clusterEndpoint ) }}
{{ printf ("\n\nIf you have set \".Values.existingInfraOverrides.enable\" as true then please provide a value for the existing Opensearch domainName, arn, clusterEndpoint: \".Values.existingInfraOverrides.domainName\" and \".Values.existingInfraOverrides.arn\" and \".Values.existingInfraOverrides.clusterEndpoint\"") | fail }}
{{- end }}
ARN: {{ .Values.existingInfraOverrides.arn }}
domainId: {{ .Values.global.awsAccountNumber }}/{{ .Values.existingInfraOverrides.domainName }}
endpoint: {{ .Values.existingInfraOverrides.clusterEndpoint }}
protocol: {{ .Values.existingInfraOverrides.protocol }}
port: {{ .Values.existingInfraOverrides.port | quote }}
{{- end }}

{{/*
  Defines extra environment variables for the container
*/}}
{{- define "opensearch.localDeploymentExtraEnvVars" -}}
{{- if .Values.localDeployment.extraEnvVars }}
{{- range .Values.localDeployment.extraEnvVars -}}
- name: {{ .name }}
  value: {{ .value | quote }}
{{- end }}
{{- end }}
{{- end }}
